@@ -1,9 +1,10 @@
 """PyVista Scalar bar module."""
+import weakref
 
 import numpy as np
 
 import pyvista
-from pyvista import _vtk
+from pyvista import MAX_N_COLOR_BARS, _vtk
 
 from .colors import Color
 from .tools import parse_font_family
@@ -14,7 +15,7 @@ class ScalarBars:
 
     def __init__(self, plotter):
         """Initialize ScalarBars."""
-        self._plotter = plotter
+        self._plotter = weakref.proxy(plotter)
         self._scalar_bar_ranges = {}
         self._scalar_bar_mappers = {}
         self._scalar_bar_actors = {}
@@ -78,7 +79,7 @@ class ScalarBars:
 
         render : bool, optional
             Render upon scalar bar removal.  Set this to ``False`` to
-            stop the render window from rendering when an scalar bar
+            stop the render window from rendering when a scalar bar
             is removed.
 
         Examples
@@ -201,7 +202,7 @@ class ScalarBars:
             Sets the size of the title font.  Defaults to ``None`` and is sized
             according to :attr:`pyvista.themes.DefaultTheme.font`.
 
-        color : color_like, optional
+        color : ColorLike, optional
             Either a string, rgb list, or hex color string.  Default
             set by :attr:`pyvista.themes.DefaultTheme.font`.  Can be
             in one of the following formats:
@@ -276,7 +277,7 @@ class ScalarBars:
         above_label : str, optional
             String annotation for values above the scalars range.
 
-        background_color : color_like, optional
+        background_color : ColorLike, optional
             The color used for the background in RGB format.
 
         n_colors : int, optional
@@ -374,12 +375,13 @@ class ScalarBars:
 
         # Automatically choose location if not specified
         if position_x is None or position_y is None:
-            try:
-                slot = min(self._plotter._scalar_bar_slots)
-                self._plotter._scalar_bar_slots.remove(slot)
-                self._plotter._scalar_bar_slot_lookup[title] = slot
-            except:
-                raise RuntimeError('Maximum number of color bars reached.')
+            if not self._plotter._scalar_bar_slots:
+                raise RuntimeError(f'Maximum number of color bars ({MAX_N_COLOR_BARS}) reached.')
+
+            slot = min(self._plotter._scalar_bar_slots)
+            self._plotter._scalar_bar_slots.remove(slot)
+            self._plotter._scalar_bar_slot_lookup[title] = slot
+
             if position_x is None:
                 if vertical:
                     position_x = theme.colorbar_vertical.position_x
@@ -408,7 +410,7 @@ class ScalarBars:
             if fill:
                 scalar_bar.DrawBackgroundOn()
 
-            lut = _vtk.vtkLookupTable()
+            lut = pyvista.LookupTable()
             lut.DeepCopy(mapper.lookup_table)
             ctable = _vtk.vtk_to_numpy(lut.GetTable())
             alphas = ctable[:, -1][:, np.newaxis] / 255.0
@@ -420,8 +422,12 @@ class ScalarBars:
             lut = mapper.lookup_table
 
         scalar_bar.SetLookupTable(lut)
-        if n_colors is not None:
-            scalar_bar.SetMaximumNumberOfColors(n_colors)
+        if n_colors is None:
+            # ensure the number of colors in the scalarbar's lookup table is at
+            # least the number in the mapper
+            n_colors = mapper.lookup_table.n_values
+
+        scalar_bar.SetMaximumNumberOfColors(n_colors)
 
         if n_labels < 1:
             scalar_bar.SetDrawTickLabels(False)
@@ -432,12 +438,18 @@ class ScalarBars:
         if nan_annotation:
             scalar_bar.DrawNanAnnotationOn()
 
-        if above_label:
+        if above_label is not None:
             scalar_bar.DrawAboveRangeSwatchOn()
             scalar_bar.SetAboveRangeAnnotation(above_label)
-        if below_label:
+        elif lut.above_range_color:
+            scalar_bar.DrawAboveRangeSwatchOn()
+            scalar_bar.SetAboveRangeAnnotation('above')
+        if below_label is not None:
             scalar_bar.DrawBelowRangeSwatchOn()
             scalar_bar.SetBelowRangeAnnotation(below_label)
+        elif lut.below_range_color:
+            scalar_bar.DrawBelowRangeSwatchOn()
+            scalar_bar.SetBelowRangeAnnotation('below')
 
         # edit the size of the colorbar
         scalar_bar.SetHeight(height)
