@@ -1,17 +1,14 @@
 """Module containing useful plotting tools."""
 
-from collections.abc import Sequence
 from enum import Enum
 import os
 import platform
 from subprocess import PIPE, Popen
-import warnings
 
 import numpy as np
 
 import pyvista
 from pyvista import _vtk
-from pyvista.utilities import PyvistaDeprecationWarning
 
 from .colors import Color
 
@@ -58,7 +55,7 @@ def _system_supports_plotting():
     # mac case
     if platform.system() == 'Darwin':
         # check if finder available
-        proc = Popen(["pgrep", "-qx", "Finder"], stdout=PIPE, stderr=PIPE)
+        proc = Popen(["pgrep", "-qx", "Finder"], stdout=PIPE, stderr=PIPE, encoding="utf8")
         proc.communicate()
         if proc.returncode == 0:
             return True
@@ -68,7 +65,7 @@ def _system_supports_plotting():
 
     # Linux case
     try:
-        proc = Popen(["xset", "-q"], stdout=PIPE, stderr=PIPE)
+        proc = Popen(["xset", "-q"], stdout=PIPE, stderr=PIPE, encoding="utf8")
         proc.communicate()
         return proc.returncode == 0
     except OSError:
@@ -126,16 +123,16 @@ def create_axes_marker(
 
     Parameters
     ----------
-    label_color : color_like, optional
-        Unknown
+    label_color : ColorLike, optional
+        Color of the label text.
 
-    x_color : color_like, optional
+    x_color : ColorLike, optional
         Color of the x axis text.
 
-    y_color : color_like, optional
+    y_color : ColorLike, optional
         Color of the y axis text.
 
-    z_color : color_like, optional
+    z_color : ColorLike, optional
         Color of the z axis text.
 
     xlabel : str, optional
@@ -153,23 +150,55 @@ def create_axes_marker(
     line_width : float, optional
         The width of the marker lines.
 
-    cone_radius: float, optional
+    cone_radius : float, optional
         The radius of the axes arrow tips.
 
-    shaft_length: float, optional
+    shaft_length : float, optional
         The length of the axes arrow shafts.
 
-    ambient: float, optional
-        The ambient of the axes arrows.
+    tip_length : float, optional
+        Length of the tip.
 
-    label_size: sequence, optoinal
-        The width and height of the axes label actors.
+    ambient : float, optional
+        The ambient of the axes arrows. Value should be between 0 and 1.
+
+    label_size : sequence, optional
+        The width and height of the axes label actors. Values should be between
+        0 and 1. For example ``(0.2, 0.1)``.
 
     Returns
     -------
     vtk.vtkAxesActor
         Axes actor.
 
+    Examples
+    --------
+    Create the default axes marker.
+
+    >>> import pyvista as pv
+    >>> marker = pv.create_axes_marker()
+    >>> pl = pv.Plotter()
+    >>> _ = pl.add_actor(marker)
+    >>> pl.show()
+
+    Create an axes marker at the origin with custom colors and axis labels.
+
+    >>> import pyvista as pv
+    >>> marker = pv.create_axes_marker(
+    ...     line_width=4,
+    ...     ambient=0.0,
+    ...     x_color="#378df0",
+    ...     y_color="#ab2e5d",
+    ...     z_color="#f7fb9a",
+    ...     xlabel="X Axis",
+    ...     ylabel="Y Axis",
+    ...     zlabel="Z Axis",
+    ...     label_size=(0.1, 0.1),
+    ... )
+    >>> pl = pv.Plotter()
+    >>> _ = pl.add_actor(marker)
+    >>> pl.show()
+
     """
     x_color = Color(x_color, default_color=pyvista.global_theme.axes.x_color)
     y_color = Color(y_color, default_color=pyvista.global_theme.axes.y_color)
@@ -243,16 +272,16 @@ def create_axes_orientation_box(
     text_scale : float, optional
         Size of the text relative to the faces.
 
-    edge_color : color_like, optional
+    edge_color : ColorLike, optional
         Color of the edges.
 
-    x_color : color_like, optional
+    x_color : ColorLike, optional
         Color of the x axis text.
 
-    y_color : color_like, optional
+    y_color : ColorLike, optional
         Color of the y axis text.
 
-    z_color : color_like, optional
+    z_color : ColorLike, optional
         Color of the z axis text.
 
     xlabel : str, optional
@@ -264,22 +293,22 @@ def create_axes_orientation_box(
     zlabel : str, optional
         Text used for the z axis.
 
-    x_face_color : color_like, optional
+    x_face_color : ColorLike, optional
         Color used for the x axis arrow.  Defaults to theme axes
         parameters.
 
-    y_face_color : color_like, optional
+    y_face_color : ColorLike, optional
         Color used for the y axis arrow.  Defaults to theme axes
         parameters.
 
-    z_face_color : color_like, optional
+    z_face_color : ColorLike, optional
         Color used for the z axis arrow.  Defaults to theme axes
         parameters.
 
     color_box : bool, optional
         Enable or disable the face colors.  Otherwise, box is white.
 
-    label_color : color_like, optional
+    label_color : ColorLike, optional
         Color of the labels.
 
     labels_off : bool, optional
@@ -372,10 +401,9 @@ def create_axes_orientation_box(
         cube_mapper.SetColorModeToDirectScalars()
         cube_mapper.Update()
 
-        cube_actor = _vtk.vtkActor()
-        cube_actor.SetMapper(cube_mapper)
-        cube_actor.GetProperty().BackfaceCullingOn()
-        cube_actor.GetProperty().SetOpacity(opacity)
+        cube_actor = pyvista.Actor(mapper=cube_mapper)
+        cube_actor.prop.culling = 'back'
+        cube_actor.prop.opacity = opacity
 
         prop_assembly = _vtk.vtkPropAssembly()
         prop_assembly.AddPart(axes_actor)
@@ -420,21 +448,38 @@ def opacity_transfer_function(mapping, n_colors, interpolate=True, kind='quadrat
     ----------
     mapping : list(float) or str
         The opacity mapping to use. Can be a ``str`` name of a predefined
-        mapping including 'linear', 'geom', 'sigmoid', 'sigmoid_3-10'.
-        Append an '_r' to any of those names to reverse that mapping.
-        This can also be a custom array/list of values that will be
-        interpolated across the ``n_color`` range for user defined mappings.
+        mapping including ``'linear'``, ``'geom'``, ``'sigmoid'``,
+        ``'sigmoid_3-10'``. Append an ``'_r'`` to any of those names to
+        reverse that mapping. This can also be a custom array/list of values
+        that will be interpolated across the ``n_color`` range for user
+        defined mappings.
 
     n_colors : int
         The amount of colors that the opacities must be mapped to.
 
     interpolate : bool
-        Flag on whether or not to interpolate the opacity mapping for all colors
+        Flag on whether or not to interpolate the opacity mapping for all
+        colors.
 
     kind : str
-        The interepolation kind if ``interpolate`` is true and ``scipy`` is
-        available. Options are ('linear', 'nearest', 'zero', 'slinear',
-        'quadratic', 'cubic', 'previous', 'next'.
+        The interpolation kind if ``interpolate`` is ``True`` and ``scipy``
+        is available. If ``scipy`` is not available, linear interpolation
+        is always used. Options are:
+
+        - ``'linear'``
+        - ``'nearest'``
+        - ``'zero'``
+        - ``'slinear'``
+        - ``'quadratic'``
+        - ``'cubic'``
+        - ``'previous'``
+        - ``'next'``
+
+    Returns
+    -------
+    numpy.ndarray
+        Array of ``numpy.uint8`` values ``n_colors`` long containing the
+        [0-255] opacity mapping values.
 
     Examples
     --------
@@ -473,7 +518,10 @@ def opacity_transfer_function(mapping, n_colors, interpolate=True, kind='quadrat
         try:
             return transfer_func[mapping]
         except KeyError:
-            raise KeyError(f'opactiy transfer function ({mapping}) unknown.')
+            raise ValueError(
+                f'Opacity transfer function ({mapping}) unknown. '
+                f'Valid options: {list(transfer_func.keys())}'
+            ) from None
     elif isinstance(mapping, (np.ndarray, list, tuple)):
         mapping = np.array(mapping)
         if mapping.size == n_colors:
@@ -510,114 +558,6 @@ def opacity_transfer_function(mapping, n_colors, interpolate=True, kind='quadrat
     raise TypeError(f'Transfer function type ({type(mapping)}) not understood')
 
 
-def parse_color(color, opacity=None, default_color=None):  # pragma: no cover
-    """Parse color into a VTK friendly RGB(A) tuple.
-
-    .. deprecated:: 0.34.0
-        Use :class:`Color` to parse and convert colors instead.
-
-    If ``color`` is a sequence of RGBA floats, the ``opacity`` parameter
-    is ignored.
-
-    Values returned will be between 0 and 1.
-
-    Parameters
-    ----------
-    color : color_like
-        Either a string, RGB sequence, RGBA sequence, or hex color string.
-        RGB(A) sequences should only contain values between 0 and 1.
-        For example:
-
-        * ``'white'``
-        * ``'w'``
-        * ``[1.0, 1.0, 1.0]``
-        * ``[0.5, 1.0, 0.7, 1.0]``
-        * ``'#FFFFFF'``
-
-    opacity : float, optional
-        Default opacity of the returned color. Used when ``color`` is
-        not a length 4 RGBA sequence. Only opacities between 0 and 1
-        are allowed.
-
-    default_color : color_like, optional
-        Default color to use when ``color`` is None.  If this value is
-        ``None``, then defaults to the global theme color.  Format is
-        identical to ``color``.
-
-    Returns
-    -------
-    tuple
-        Either a length 3 RGB sequence if opacity is unset, or an RGBA
-        sequence when ``opacity`` is set or the input ``color`` is an
-        RGBA sequence.
-
-    Examples
-    --------
-    >>> import pyvista
-    >>> pyvista.parse_color('blue')
-    (0.0, 0.0, 1.0)
-
-    >>> pyvista.parse_color('k')
-    (0.0, 0.0, 0.0)
-
-    >>> pyvista.parse_color('#FFFFFF')
-    (1.0, 1.0, 1.0)
-
-    >>> pyvista.parse_color((0.4, 0.3, 0.4, 1))
-    (0.4, 0.3, 0.4, 1.0)
-
-    """
-    # Deprecated on v0.34.0, estimated removal on v0.37.0
-    warnings.warn(
-        "The usage of `parse_color` is deprecated in favor of the new `Color` class.",
-        PyvistaDeprecationWarning,
-    )
-    color_valid = True
-    if color is None:
-        if default_color is None:
-            color = pyvista.global_theme.color
-        else:
-            color = default_color
-    if isinstance(color, str):
-        color = Color(color).float_rgb
-    elif isinstance(color, (Sequence, np.ndarray)):
-        try:
-            color = np.asarray(color, dtype=np.float64)
-            if (
-                color.ndim != 1
-                or color.size not in (3, 4)
-                or not np.all((0 <= color) & (color <= 1))
-            ):
-                color_valid = False
-            elif len(color) == 4:
-                opacity = color[3]
-                color = color[:3]
-        except ValueError:
-            color_valid = False
-    else:
-        color_valid = False
-    if not color_valid:
-        raise ValueError(
-            "\n"
-            f"\tInvalid color input: ({color})\n"
-            "\tMust be string, rgb list, or hex color string.  For example:\n"
-            "\t\tcolor='white'\n"
-            "\t\tcolor='w'\n"
-            "\t\tcolor=[1, 1, 1]\n"
-            "\t\tcolor='#FFFFFF'"
-        )
-    if opacity is not None:
-        if isinstance(opacity, (float, int)) and 0 <= opacity <= 1:
-            color = [color[0], color[1], color[2], float(opacity)]
-        else:
-            raise ValueError(
-                "\n"
-                f"\tInvalid opacity input: {opacity}\n"
-                "\tMust be a scalar value between 0 and 1."
-            )
-    return tuple(color)
-
-
 def parse_font_family(font_family):
     """Check font name."""
     font_family = font_family.lower()
