@@ -146,7 +146,7 @@ def convert_array(arr, name=None, deep=False, array_type=None):
         A numpy array or vtkDataArry to convert.
     name : str, optional
         The name of the data array for VTK.
-    deep : bool, optional
+    deep : bool, default: False
         If input is numpy array then deep copy values.
     array_type : int, optional
         VTK array type ID as specified in specified in ``vtkType.h``.
@@ -354,12 +354,12 @@ def get_array(mesh, name, preference='cell', err=False) -> Optional[np.ndarray]:
     name : str
         The name of the array to get the range.
 
-    preference : str, optional
+    preference : str, default: "cell"
         When scalars is specified, this is the preferred array type to
         search for in the dataset.  Must be either ``'point'``,
         ``'cell'``, or ``'field'``.
 
-    err : bool, optional
+    err : bool, default: False
         Whether to throw an error if array is not present.
 
     Returns
@@ -417,12 +417,12 @@ def get_array_association(mesh, name, preference='cell', err=False) -> FieldAsso
     name : str
         The name of the array.
 
-    preference : str, optional
+    preference : str, default: "cell"
         When scalars is specified, this is the preferred array type to
         search for in the dataset.  Must be either ``'point'``,
         ``'cell'``, or ``'field'``.
 
-    err : bool, optional
+    err : bool, default: False
         Boolean to control whether to throw an error if array is not
         present.
 
@@ -471,11 +471,11 @@ def vtk_points(points, deep=True, force_float=False):
         Points to convert.  Should be 1 or 2 dimensional.  Accepts a
         single point or several points.
 
-    deep : bool, optional
+    deep : bool, default: True
         Perform a deep copy of the array.  Only applicable if
         ``points`` is a :class:`numpy.ndarray`.
 
-    force_float : bool, optional
+    force_float : bool, default: False
         Casts the datatype to ``float32`` if points datatype is
         non-float.  Set this to ``False`` to allow non-float types,
         though this may lead to truncation of intermediate floats
@@ -525,11 +525,26 @@ def vtk_points(points, deep=True, force_float=False):
             f'Shape is {points.shape} and should be (X, 3)'
         )
 
+    # use the underlying vtk data if present to avoid memory leaks
+    if not deep and isinstance(points, pyvista.pyvista_ndarray):
+        if points.VTKObject is not None:
+            vtk_object = points.VTKObject
+
+            # we can only use the underlying data if `points` is not a slice of
+            # the VTK data object
+            if vtk_object.GetSize() == points.size:
+                vtkpts = _vtk.vtkPoints()
+                vtkpts.SetData(points.VTKObject)
+                return vtkpts
+            else:
+                deep = True
+
     # points must be contiguous
     points = np.require(points, requirements=['C'])
     vtkpts = _vtk.vtkPoints()
     vtk_arr = _vtk.numpy_to_vtk(points, deep=deep)
     vtkpts.SetData(vtk_arr)
+
     return vtkpts
 
 
@@ -559,7 +574,7 @@ def line_segments_from_points(points):
     >>> import pyvista
     >>> import numpy as np
     >>> points = np.array([[0, 0, 0], [1, 0, 0], [1, 0, 0], [1, 1, 0]])
-    >>> lines = pyvista.lines_from_points(points)
+    >>> lines = pyvista.line_segments_from_points(points)
     >>> lines.plot()
 
     """
@@ -591,7 +606,7 @@ def lines_from_points(points, close=False):
         segments. For example, two line segments would be represented
         as ``np.array([[0, 0, 0], [1, 0, 0], [1, 1, 0]])``.
 
-    close : bool, optional
+    close : bool, default: False
         If ``True``, close the line segments into a loop.
 
     Returns
@@ -862,6 +877,11 @@ def wrap(dataset):
     * 3D :class:`trimesh.Trimesh` mesh.
     * 3D :class:`meshio.Mesh` mesh.
 
+    .. versionchanged:: 0.38.0
+        If the passed object is already a wrapped PyVista object, then
+        this is no-op and will return that object directly. In previous
+        versions of PyVista, this would perform a shallow copy.
+
     Parameters
     ----------
     dataset : :class:`numpy.ndarray`, :class:`trimesh.Trimesh`, or VTK object
@@ -934,6 +954,10 @@ def wrap(dataset):
     if dataset is None:
         return
 
+    if isinstance(dataset, tuple(pyvista._wrappers.values())):
+        # Return object if it is already wrapped
+        return dataset
+
     # Check if dataset is a numpy array.  We do this first since
     # pyvista_ndarray contains a VTK type that we don't want to
     # directly wrap.
@@ -943,7 +967,10 @@ def wrap(dataset):
         if dataset.ndim > 1 and dataset.ndim < 3 and dataset.shape[1] == 3:
             return pyvista.PolyData(dataset)
         elif dataset.ndim == 3:
-            mesh = pyvista.UniformGrid(dims=dataset.shape)
+            mesh = pyvista.UniformGrid(dimensions=dataset.shape)
+            if isinstance(dataset, pyvista.pyvista_ndarray):
+                # this gets rid of pesky VTK reference since we're raveling this
+                dataset = np.array(dataset, copy=False)
             mesh['values'] = dataset.ravel(order='F')
             mesh.active_scalars_name = 'values'
             return mesh
@@ -960,7 +987,7 @@ def wrap(dataset):
         try:
             return pyvista._wrappers[key](dataset)
         except KeyError:
-            logging.warning(f'VTK data type ({key}) is not currently supported by pyvista.')
+            raise TypeError(f'VTK data type ({key}) is not currently supported by pyvista.')
         return
 
     # wrap meshio
@@ -1003,14 +1030,31 @@ def numpy_to_texture(image):
     Parameters
     ----------
     image : numpy.ndarray
-        Numpy image array.
+        Numpy image array. Texture datatype expected to be ``np.uint8``.
 
     Returns
     -------
-    vtkTexture
-        VTK texture.
+    pyvista.Texture
+        PyVista texture.
+
+    Examples
+    --------
+    Create an all white texture.
+
+    >>> import pyvista as pv
+    >>> import numpy as np
+    >>> tex_arr = np.ones((1024, 1024, 3), dtype=np.uint8) * 255
+    >>> tex = pv.numpy_to_texture(tex_arr)
 
     """
+    if image.dtype != np.uint8:
+        image = image.astype(np.uint8)
+        warnings.warn(
+            'Expected `image` dtype to be ``np.uint8``. `image` has been copied '
+            'and converted to np.uint8.',
+            UserWarning,
+        )
+
     return pyvista.Texture(image)
 
 
@@ -1062,7 +1106,7 @@ def fit_plane_to_points(points, return_meta=False):
     points : sequence
         Size ``[N x 3]`` sequence of points to fit a plane through.
 
-    return_meta : bool, optional
+    return_meta : bool, default: False
         If ``True``, also returns the center and normal used to
         generate the plane.
 
@@ -1124,10 +1168,10 @@ def raise_not_matching(scalars, dataset):
     """
     if isinstance(dataset, _vtk.vtkTable):
         raise ValueError(
-            f'Number of scalars ({scalars.size}) must match number of rows ({dataset.n_rows}).'
+            f'Number of scalars ({scalars.shape[0]}) must match number of rows ({dataset.n_rows}).'
         )
     raise ValueError(
-        f'Number of scalars ({scalars.size}) '
+        f'Number of scalars ({scalars.shape[0]}) '
         f'must match either the number of points ({dataset.n_points}) '
         f'or the number of cells ({dataset.n_cells}).'
     )
@@ -1178,7 +1222,7 @@ def try_callback(func, *args):
         formatted_exception = 'Encountered issue in callback (most recent call last):\n' + ''.join(
             traceback.format_list(stack) + traceback.format_exception_only(etype, exc)
         ).rstrip('\n')
-        logging.warning(formatted_exception)
+        warnings.warn(formatted_exception)
 
 
 def check_depth_peeling(number_of_peels=100, occlusion_ratio=0.0):
@@ -1191,10 +1235,10 @@ def check_depth_peeling(number_of_peels=100, occlusion_ratio=0.0):
 
     Parameters
     ----------
-    number_of_peels : int, optional
+    number_of_peels : int, default: 100
         Maximum number of depth peels.
 
-    occlusion_ratio : float, optional
+    occlusion_ratio : float, default: 0.0
         Occlusion ratio.
 
     Returns
@@ -1286,7 +1330,7 @@ class ProgressMonitor:
     algorithm
         VTK algorithm or filter.
 
-    message : str, optional
+    message : str, default: ""
         Message to display in the progress bar.
 
     scaling : float, optional
@@ -1294,7 +1338,7 @@ class ProgressMonitor:
 
     """
 
-    def __init__(self, algorithm, message="", scaling=100):
+    def __init__(self, algorithm, message="", scaling=None):
         """Initialize observer."""
         try:
             from tqdm import tqdm  # noqa
@@ -1379,16 +1423,16 @@ def axis_rotation(points, angle, inplace=False, deg=True, axis='z'):
     angle : float
         Rotation angle.
 
-    inplace : bool, optional
+    inplace : bool, default: False
         Updates points in-place while returning nothing.
 
-    deg : bool, optional
+    deg : bool, default: True
         If ``True``, the angle is interpreted as degrees instead of
-        radians. Default is ``True``.
+        radians.
 
-    axis : str, optional
+    axis : str, default: "z"
         Name of axis to rotate about. Valid options are ``'x'``, ``'y'``,
-        and ``'z'``. Default value is ``'z'``.
+        and ``'z'``.
 
     Returns
     -------
@@ -1444,13 +1488,13 @@ def cubemap(path='', prefix='', ext='.jpg'):
 
     Parameters
     ----------
-    path : str, optional
+    path : str, default: ""
         Directory containing the cubemap images.
 
-    prefix : str, optional
+    prefix : str, default: ""
         Prefix to the filename.
 
-    ext : str, optional
+    ext : str, default: ".jpg"
         The filename extension.  For example ``'.jpg'``.
 
     Returns
